{% extends 'bootstrap/base.html' %}


{% block styles %}
{{ super() }}
	<style>
		body { background: #e8f1f9; }
	</style>
{% endblock %}


{% block title %}
Database Result
{% endblock %}


{% block content %}

<div class="container">
  <div class="row pb-5">
    <div class="col-md-10 col-lg-8 mx-lg-auto mx-md-auto">

    	<h1 class="pt-5 pb-2">Database Result</h1>

	{% if message %}

		<!-- the form was submitted and message exists -->
		<p class="lead"><strong>{{ message }}</strong></p>
		<meta http-equiv="refresh" content="3;url={{ redirect }}" />

	{% else %}

		<p class="lead">There is nothing for you here.</p>

	{% endif %}

		<!-- links -->
		<p><a href="{{ url_for('templates_bp.index') }}">Return to the index.</a></p>
		</div>
	</div>
</div>

{% endblock %}
