body {
background-color: #8D7F94;
background-image: radial-gradient(#935671 1px, transparent 0);
background-size: 3px 3px;
background-position: -19px -19px;
/*background-color: #9A5029;*/
font-family: Open Sans,sans-serif;
font-weight: 400;
font-size: 16px;
}

.card-body {
    color: #9A5029;
}

.dropdown-submenu {
  position: relative;
}

.dropdown-submenu .dropdown-menu {
  top: 0;
  left: 100%;
  margin-top: -1px;
}

.dropdown-menu li {
position: relative;
}
.dropdown-menu .dropdown-submenu {
display: none;
position: absolute;
left: 100%;
top: -7px;
}
.dropdown-menu .dropdown-submenu-left {
right: 100%;
left: auto;
}
.dropdown-menu > li:hover > .dropdown-submenu {
display: block;
}

.dropdown-hover:hover>.dropdown-menu {
display: inline-block;
}

.dropdown-hover>.dropdown-toggle:active {
Without this, clicking will make it sticky
pointer-events: none;
}

.btn-outline-secondary {
  color: #fff;
  border-color: #fff;
}
