<main class="bd-main order-1">

{% extends '_nav.html' %}

{% block content %}
	<div class="container">
	  <div class="row pb-5">
		  		    <div class="col-md-10 col-lg-20 mx-lg-auto mx-md-auto" style="left: -60px;bottom: -65px;">
		<button type="button" class="btn btn-outline-secondary" onclick="history.back()">
			<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-left" viewBox="0 0 16 16">
			  <path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"></path>
			</svg>
		<span class="visually-hidden">Button</span>
		</button>
	</div>
		<div class="shadow col-md-10 col-lg-8 mx-lg-auto mx-md-auto border border-2 bg-light">
			{% include '_nav_top.html' %}

			        <ul style="padding-top: 10px;">
			<br>
        </ul>
				<div class="card" style="width: 18rem; display:inline-block;">
				  <div class="card-body">
					<h5 class="card-title">{{ Parent['lastname'] }}</h5>
					<h6 class="card-subtitle mb-2"><i>{{ Parent['firstname'] }}</i></h6>
					<p class="card-text">{{ Parent['address'] }}<br>{{ Parent['zipcode'] }} {{ Parent['city'] }}</p>
					<p><a href="tel:{{ Parent['phone'] }}" class="card-link">{{ Parent['phone'] }}</a><br>
					<a href="mailto:{{ Parent['email'] }}" class="card-link">{{ Parent['email'] }}</a></p>
				  </div>


				</div>

			<ul></ul>
			<!--		Delete Box-->
		<div class="modal fade" id="exampleModalCenter{{ Parent['id'] }}">
            <div class="modal-dialog modal-dialog-centered" role="document">
              <div class="modal-content">
                <div class="modal-header">
                  <h5 class="modal-title" id="exampleModalLongTitle{{Parent['id']}}">Ouder permanent verwijderen?</h5>
                  <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                  </button>
                </div>
                <div class="modal-body">
                  <p><b><i>{{ Parent['firstname'] }} {{ Parent['lastname'] }}</i></b> permanent verwijderen?</p>
                </div>
                <div class="modal-footer">
                  <button type="button" class="btn btn-secondary" data-dismiss="modal">Annuleren</button>
                  <form action="{{ url_for('parents_bp.remove_parent', pid=Parent['id']) }}">
					  <input type="submit" value="Verwijderen" class="btn btn-danger">
                  </form>
                </div>
              </div>
            </div>
			</div>
		</div>
<!--	End	Delete Box-->
	</div>

	<script type="module">
		ShowEditOption("Parent", "{{ url_for('parents_bp.edit_parent', pid=Parent['id'] ) }}")
		ShowDeleteOption("Parent", "{{ Parent['id'] }}")
		Collapse("Parent")
	</script>
	  </div>
	</div>
{% endblock %}
</main>