<main class="bd-main order-1">

{% extends '_nav.html' %}
{% import "bootstrap/wtf.html" as wtf %}

{% block content %}
<div class="container">
	<div class="row pb-5">
				  		    <div class="col-md-10 col-lg-20 mx-lg-auto mx-md-auto" style="left: -60px;bottom: -65px;">
		<button type="button" class="btn btn-outline-secondary" onclick="history.back()">
			<svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-chevron-left" viewBox="0 0 16 16">
			  <path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"></path>
			</svg>
		<span class="visually-hidden">Button</span>
		</button>
	</div>
		<div class="shadow col-md-10 col-lg-8 mx-lg-auto mx-md-auto border border-2 bg-light">
		{% include '_nav_top.html' %}

<!--		<h1 class="pt-5 pb-2">Kind toevoegen</h1>-->
		<br>
		{% if message %}

			<!-- the form was submitted and message exists -->

		{% else %}

			<!-- the form is displayed when template opens via GET not POST -->

			<p class="lead alert alert-primary">Docent toevoegen.</p>

			<!-- show flash - based on WTForms validators
				 see https://pythonprogramming.net/flash-flask-tutorial/
				 get_flashed_messages() exists here because of flash()
				 in the route function
				 -->
			{% with errors = get_flashed_messages() %}
				{% if errors %}
					{% for err in errors %}
						<div class="alert alert-danger alert-dismissible" role="alert">
						<button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">×</span></button>
						{{ err }}
						</div>
					{% endfor %}
				{% endif %}
			{% endwith %}
			<!-- end of flash -->

			<!-- the form, thanks to WTForms -->
		    {{ wtf.quick_form(form1) }}

		{% endif %}

		</div>
	</div>
	<script type="module">
        Collapse("School")
        Collapse("Teachers")
    </script>
</div>
{% endblock %}
</main>