 <nav class="border-bottom navbar navbar-expand-lg navbar-light bg-light">
  <a class="navbar-brand" href="#">{{ _PageTitle }}</a>
  <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarTogglerDemo02" aria-controls="navbarTogglerDemo02" aria-expanded="false" aria-label="Toggle navigation">
    <span class="navbar-toggler-icon"></span>
  </button>

  <div class="collapse navbar-collapse" id="navbarTogglerDemo02">
    <ul class="navbar-nav mr-auto mt-2 mt-lg-0" id="navTopBar01">
      <li class="nav-item">
        <a hidden class="nav-link disabled border-left" href="#" id="btn-new">Nieuw<span class="sr-only">(current)</span></a>
      </li>
      <li class="nav-item">
        <a hidden class="nav-link disabled border-left border-right" href="#" id="btn-new-fam">Nieuw<span class="sr-only">(current)</span></a>
      </li>
      <li class="nav-item">
        <a hidden class="nav-link disabled border-left" href="#" id="btn-edit">Wijzigen <span class="sr-only">(current)</span></a>
      </li>
      <li class="nav-item">
        <a hidden class="nav-link disabled border-left border-right" href="#" id="btn-delete">Verwijderen <span class="sr-only">(current)</span></a>
      </li>
    </ul>
  </div>
</nav>