{% extends 'bootstrap/base.html' %}

{% block styles %}
{{ super() }}
	<style>
		body { background: #e8f1f9; }
	</style>
{% endblock %}

{% block title %}
{{ pagetitle }}
{% endblock %}


{% block content %}

<div class="container">
  <div class="row">
    <div class="col-md-10 col-lg-8 mx-lg-auto mx-md-auto">

      <h1 class="pt-5 pb-2">{{ pageheading }}</h1>

      <p>{{ error }}</p>

      <p><a href="{{ url_for('index') }}">Go to the index.</a></p>

    </div>
  </div>
</div>

{% endblock %}
